@@ -1,18 +1,13 @@
 from typing import TYPE_CHECKING, Any, Dict, Union
 from uuid import UUID
 
+from myst.models.types import UNSET
+
 if TYPE_CHECKING:  # Avoid circular imports.
     from myst.models.types import UUIDOrStr
     from myst.resources.resource import Resource
 
 
-class _Unset:
-    pass
-
-
-UNSET = _Unset()
-
-
 def drop_unset_values(input_dict: Dict[str, Any]) -> Dict[str, Any]:
     """Drops `UNSET` values from the specified dictionary.
 
