@@ -1,6 +1,7 @@
 import enum
 from dataclasses import dataclass
 from typing import List
+from typing import Optional
 from uuid import UUID
 
 from myst.connectors.source_connector import SourceConnector
@@ -17,6 +18,7 @@ class YesEnergyAggregation(str, enum.Enum):
 class YesEnergyItem:
     datatype: str
     object_id: int
+    forecast_vintage_offset: Optional[str] = None
 
 
 class YesEnergy(SourceConnector):
