@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.project_create import ProjectCreate
-from ...models.project_get import ProjectGet
+from myst.openapi.models.project_create import ProjectCreate
+from myst.openapi.models.project_get import ProjectGet
 
 
 def request_sync(client: Client, uuid: str, json_body: ProjectCreate) -> ProjectGet:
