@@ -4,7 +4,7 @@ from myst.openapi.models.node_job_create import NodeJobCreate
 
 
 def request_sync(client: Client, project_uuid: str, uuid: str, json_body: NodeJobCreate) -> ModelFitJobGet:
-    """Create ad-hoc fit job for model."""
+    """Create an ad hoc fit job for a model."""
 
     return client.request(
         method="post",
