@@ -1,7 +1,6 @@
 from myst.client import Client
-
-from ...models.user_create import UserCreate
-from ...models.user_get import UserGet
+from myst.openapi.models.user_create import UserCreate
+from myst.openapi.models.user_get import UserGet
 
 
 def request_sync(client: Client, json_body: UserCreate) -> UserGet:
