@@ -12,6 +12,7 @@ from myst.openapi.models.relative_timing_get import RelativeTimingGet
 class BacktestGet(base_model.BaseModel):
     """Schema for backtest get responses."""
 
+    object_: Literal["Backtest"] = Field(..., alias="object")
     uuid: str
     create_time: str
     title: str
@@ -26,6 +27,5 @@ class BacktestGet(base_model.BaseModel):
     project: str
     model: str
     creator: str
-    object_: Optional[Literal["Backtest"]] = Field("Backtest", alias="object")
     update_time: Optional[str] = None
     description: Optional[str] = None
