@@ -1,3 +1,5 @@
+from typing import Optional
+
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -12,3 +14,4 @@ class BacktestJobGet(base_model.BaseModel):
     uuid: str
     backtest: str
     state: JobState
+    seconds_to_complete: Optional[int] = None
