@@ -1,3 +1,5 @@
+from typing import Dict, Optional
+
 from pydantic import Field
 from typing_extensions import Literal
 
@@ -13,3 +15,4 @@ class BacktestResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     result_url: str
+    metrics: Optional[Dict[str, Optional[float]]] = None
