@@ -1,12 +1,12 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 from myst.models import base_model
-from myst.openapi.models.hpo_metrics import HPOMetrics
 
 
 class HPOTrial(base_model.BaseModel):
     """Represents the result of a single HPO trial."""
 
     parameters: Dict[str, Any]
-    metrics: HPOMetrics
+    metrics: Dict[str, Optional[float]]
     create_time: str
+    backtest_result_url: Optional[str] = None
