@@ -4,6 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.hpo_metric import HPOMetric
 
 
 class HyperoptCreate(base_model.BaseModel):
@@ -13,7 +14,7 @@ class HyperoptCreate(base_model.BaseModel):
 
     object_: Optional[Literal["SearchAlgorithm"]] = Field(..., alias="object")
     type: Optional[Literal["Hyperopt"]] = "Hyperopt"
-    metric: Optional[Literal["mse"]] = "mse"
+    metric: Optional[HPOMetric] = HPOMetric.RMSE
     num_trials: Optional[int] = 10
     max_concurrent_trials: Optional[int] = 1
     algorithm: Optional[Literal["TPE"]] = "TPE"
