@@ -4,6 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.openapi.models.hpo_metric import HPOMetric
 
 
 class HyperoptGet(base_model.BaseModel):
@@ -11,7 +12,7 @@ class HyperoptGet(base_model.BaseModel):
 
     See https://hyperopt.github.io/hyperopt/ for `hyperopt` reference."""
 
-    metric: Literal["mse"]
+    metric: HPOMetric
     num_trials: int
     max_concurrent_trials: int
     algorithm: Literal["TPE"]
