@@ -4,10 +4,9 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.absolute_timing_get import AbsoluteTimingGet
-from ..models.cron_timing_get import CronTimingGet
-from ..models.relative_timing_get import RelativeTimingGet
+from myst.openapi.models.absolute_timing_get import AbsoluteTimingGet
+from myst.openapi.models.cron_timing_get import CronTimingGet
+from myst.openapi.models.relative_timing_get import RelativeTimingGet
 
 
 class ModelFitPolicyGet(base_model.BaseModel):
