@@ -4,7 +4,7 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-from myst.openapi.models.time_dataset import TimeDataset
+from myst.models.time_dataset import TimeDataset
 
 
 class ModelFitResultGet(base_model.BaseModel):
