@@ -1,8 +1,7 @@
 from typing import List
 
 from myst.models import base_model
-
-from ..models.organization_get import OrganizationGet
+from myst.openapi.models.organization_get import OrganizationGet
 
 
 class OrganizationList(base_model.BaseModel):
