@@ -4,9 +4,8 @@ from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
-
-from ..models.deploy_status import DeployStatus
-from ..models.org_sharing_role import OrgSharingRole
+from myst.openapi.models.deploy_status import DeployStatus
+from myst.openapi.models.org_sharing_role import OrgSharingRole
 
 
 class ProjectUpdate(base_model.BaseModel):
