@@ -1,9 +1,10 @@
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
 
 from myst.models import base_model
+from myst.models.time_dataset import TimeDataset
 
 
 class TimeSeriesRunResultGet(base_model.BaseModel):
@@ -17,4 +18,5 @@ class TimeSeriesRunResultGet(base_model.BaseModel):
     start_time: str
     end_time: str
     as_of_time: str
+    outputs: List[TimeDataset]
     update_time: Optional[str] = None
