@@ -1,8 +1,7 @@
-from typing import TYPE_CHECKING, Union
+from typing import TYPE_CHECKING, List, Union
 from uuid import UUID
 
 from myst.adapters.utils import get_resource_uuid
-
 from myst.client import get_client
 from myst.models.types import UUIDOrStr
 from myst.openapi.api.projects.hpos.results import get_hpo_result
@@ -19,6 +18,7 @@ class HPOResult(Resource):
 
     uuid: UUID
     best_trial: HPOTrial
+    trials: List[HPOTrial]
 
     @classmethod
     def get(
