@@ -1,12 +1,13 @@
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
+from myst.adapters.timing import to_timing_create
 from myst.adapters.utils import drop_unset_values, get_resource_uuid
 from myst.client import get_client
 from myst.core.data.time_array import TimeArray
 from myst.core.time.time import Time
 from myst.core.time.time_delta import TimeDelta
 from myst.models.time_dataset import TimeDataset, TimeDatasetRow
-from myst.models.timing import ScheduleTiming, TimeRangeBoundary
+from myst.models.timing import ScheduleTiming, TimeRangeBoundary, from_time_range_boundary
 from myst.models.types import (
     UNSET,
     AxisLabels,
@@ -23,11 +24,14 @@ from myst.openapi.api.projects.time_series import (
     insert_time_series_data,
     list_all_time_series,
     query_time_series_data,
+    time_series_run_job_create,
     update_time_series,
 )
+from myst.openapi.models.node_job_create import NodeJobCreate
 from myst.openapi.models.time_series_create import TimeSeriesCreate
 from myst.openapi.models.time_series_insert import TimeSeriesInsert
 from myst.openapi.models.time_series_update import TimeSeriesUpdate
+from myst.resources.job import TimeSeriesRunJob
 from myst.resources.layer import TimeSeriesLayer
 from myst.resources.node import Node
 from myst.resources.policy import TimeSeriesRunPolicy
@@ -311,7 +315,20 @@ class TimeSeries(Node):
     def list_run_results(self) -> List[TimeSeriesRunResultMetadata]:
         return TimeSeriesRunResult.list(project=self.project, time_series=self)
 
-    def get_run_result(self, time_series_result: Union[TimeSeriesRunResultMetadata, UUIDOrStr]) -> TimeSeriesRunResult:
-        return TimeSeriesRunResult.get(
-            project=self.project, time_series=self, uuid=get_resource_uuid(time_series_result)
+    def get_run_result(self, uuid: UUIDOrStr) -> TimeSeriesRunResult:
+        return TimeSeriesRunResult.get(project=self.project, time_series=self, uuid=uuid)
+
+    def run(self, start_timing: TimeRangeBoundary, end_timing: TimeRangeBoundary) -> TimeSeriesRunJob:
+        """Create an ad hoc node run job for this time series."""
+        node_run_job = time_series_run_job_create.request_sync(
+            client=get_client(),
+            project_uuid=str(self.project),
+            uuid=str(self.uuid),
+            json_body=NodeJobCreate(
+                object="NodeJob",
+                start_timing=to_timing_create(from_time_range_boundary(start_timing)),
+                end_timing=to_timing_create(from_time_range_boundary(end_timing)),
+            ),
         )
+
+        return TimeSeriesRunJob.parse_obj(dict(node_run_job.dict(), project=self.project))
