@@ -27,12 +27,13 @@ PACKAGE_NAME_MAP: Dict[str, str] = {
     "projectsbacktests": "projects.backtests",
     "projectsbacktestsjobs": "projects.backtests.jobs",
     "projectsbacktestsresults": "projects.backtests.results",
+    "projectsdeployments": "projects.deployments",
+    "projectsedges": "projects.edges",
     "projectshpos": "projects.hpos",
     "projectshposjobs": "projects.hpos.jobs",
     "projectshposresults": "projects.hpos.results",
-    "projectsdeployments": "projects.deployments",
-    "projectsedges": "projects.edges",
     "projectsmodels": "projects.models",
+    "projectsmodelsfit_jobs": "projects.models.fit_jobs",
     "projectsmodelsfit_policies": "projects.models.fit_policies",
     "projectsmodelsfit_results": "projects.models.fit_results",
     "projectsmodelsinputs": "projects.models.inputs",
@@ -46,6 +47,7 @@ PACKAGE_NAME_MAP: Dict[str, str] = {
     "projectssources": "projects.sources",
     "projectstime_series": "projects.time_series",
     "projectstime_serieslayers": "projects.time_series.layers",
+    "projectstime_seriesrun_jobs": "projects.time_series.run_jobs",
     "projectstime_seriesrun_policies": "projects.time_series.run_policies",
     "projectstime_seriesrun_results": "projects.time_series.run_results",
     "users": "users",
